"""
Interact with and view information about users and also current user.
"""


class Users:
    # pylint: disable=too-many-public-methods
    """
    Interact with and view information about users and also current user.
    """

    def __init__(self, client):
        """
        Initialize the Users class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_the_authenticated_user(self, payload=None):
        """
        Get the authenticated user
        https://docs.github.com/rest/reference/users#get-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user"
        response = self._execute("get", url, payload)
        return response

    def update_the_authenticated_user(self, payload=None):
        """
        Update the authenticated user
        https://docs.github.com/rest/reference/users/#update-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user"
        response = self._execute("patch", url, payload)
        return response

    def list_users_blocked_by_the_authenticated_user(self, payload=None):
        """
        List users blocked by the authenticated user
        https://docs.github.com/rest/reference/users#list-users-blocked-by-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/blocks"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_user_is_blocked_by_the_authenticated_user(self, username, payload=None):
        """
        Check if a user is blocked by the authenticated user
        https://docs.github.com/rest/reference/users#check-if-a-user-is-blocked-by-the-authenticated-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/blocks/{username}"
        response = self._execute("get", url, payload)
        return response

    def block_a_user(self, username, payload=None):
        """
        Block a user
        https://docs.github.com/rest/reference/users#block-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/blocks/{username}"
        response = self._execute("put", url, payload)
        return response

    def unblock_a_user(self, username, payload=None):
        """
        Unblock a user
        https://docs.github.com/rest/reference/users#unblock-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/blocks/{username}"
        response = self._execute("delete", url, payload)
        return response

    def set_primary_email_visibility_for_the_authenticated_user(self, payload=None):
        """
        Set primary email visibility for the authenticated user
        https://docs.github.com/rest/reference/users#set-primary-email-visibility-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/email/visibility"
        response = self._execute("patch", url, payload)
        return response

    def list_email_addresses_for_the_authenticated_user(self, payload=None):
        """
        List email addresses for the authenticated user
        https://docs.github.com/rest/reference/users#list-email-addresses-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/emails"
        response = self._execute("get", url, payload)
        return response

    def add_an_email_address_for_the_authenticated_user(self, payload=None):
        """
        Add an email address for the authenticated user
        https://docs.github.com/rest/reference/users#add-an-email-address-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/emails"
        response = self._execute("post", url, payload)
        return response

    def delete_an_email_address_for_the_authenticated_user(self, payload=None):
        """
        Delete an email address for the authenticated user
        https://docs.github.com/rest/reference/users#delete-an-email-address-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/emails"
        response = self._execute("delete", url, payload)
        return response

    def list_followers_of_the_authenticated_user(self, payload=None):
        """
        List followers of the authenticated user
        https://docs.github.com/rest/reference/users#list-followers-of-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/followers"
        response = self._execute("get", url, payload)
        return response

    def list_the_people_the_authenticated_user_follows(self, payload=None):
        """
        List the people the authenticated user follows
        https://docs.github.com/rest/reference/users#list-the-people-the-authenticated-user-follows
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/following"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_person_is_followed_by_the_authenticated_user(self, username, payload=None):
        """
        Check if a person is followed by the authenticated user
        https://docs.github.com/rest/reference/users#check-if-a-person-is-followed-by-the-authenticated-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/following/{username}"
        response = self._execute("get", url, payload)
        return response

    def follow_a_user(self, username, payload=None):
        """
        Follow a user
        https://docs.github.com/rest/reference/users#follow-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/following/{username}"
        response = self._execute("put", url, payload)
        return response

    def unfollow_a_user(self, username, payload=None):
        """
        Unfollow a user
        https://docs.github.com/rest/reference/users#unfollow-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/user/following/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_gpg_keys_for_the_authenticated_user(self, payload=None):
        """
        List GPG keys for the authenticated user
        https://docs.github.com/rest/reference/users#list-gpg-keys-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/gpg_keys"
        response = self._execute("get", url, payload)
        return response

    def create_a_gpg_key_for_the_authenticated_user(self, payload=None):
        """
        Create a GPG key for the authenticated user
        https://docs.github.com/rest/reference/users#create-a-gpg-key-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/gpg_keys"
        response = self._execute("post", url, payload)
        return response

    def get_a_gpg_key_for_the_authenticated_user(self, gpg_key_id, payload=None):
        """
        Get a GPG key for the authenticated user
        https://docs.github.com/rest/reference/users#get-a-gpg-key-for-the-authenticated-user
        Attributes:
        Path Parameters:
        gpg_key_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/gpg_keys/{gpg_key_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_gpg_key_for_the_authenticated_user(self, gpg_key_id, payload=None):
        """
        Delete a GPG key for the authenticated user
        https://docs.github.com/rest/reference/users#delete-a-gpg-key-for-the-authenticated-user
        Attributes:
        Path Parameters:
        gpg_key_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/gpg_keys/{gpg_key_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_public_ssh_keys_for_the_authenticated_user(self, payload=None):
        """
        List public SSH keys for the authenticated user
        https://docs.github.com/rest/reference/users#list-public-ssh-keys-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/keys"
        response = self._execute("get", url, payload)
        return response

    def create_a_public_ssh_key_for_the_authenticated_user(self, payload=None):
        """
        Create a public SSH key for the authenticated user
        https://docs.github.com/rest/reference/users#create-a-public-ssh-key-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/keys"
        response = self._execute("post", url, payload)
        return response

    def get_a_public_ssh_key_for_the_authenticated_user(self, key_id, payload=None):
        """
        Get a public SSH key for the authenticated user
        https://docs.github.com/rest/reference/users#get-a-public-ssh-key-for-the-authenticated-user
        Attributes:
        Path Parameters:
        key_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/keys/{key_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_public_ssh_key_for_the_authenticated_user(self, key_id, payload=None):
        """
        Delete a public SSH key for the authenticated user
        https://docs.github.com/rest/reference/users#delete-a-public-ssh-key-for-the-authenticated-user
        Attributes:
        Path Parameters:
        key_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/keys/{key_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_public_email_addresses_for_the_authenticated_user(self, payload=None):
        """
        List public email addresses for the authenticated user
        https://docs.github.com/rest/reference/users#list-public-email-addresses-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/public_emails"
        response = self._execute("get", url, payload)
        return response

    def list_users(self, payload=None):
        """
        List users
        https://docs.github.com/rest/reference/users#list-users
        Attributes:
        Path Parameters:

        Payload Parameters:
        since-user
         per-page
        """
        url = self._base_url + "/users"
        response = self._execute("get", url, payload)
        return response

    def get_a_user(self, username, payload=None):
        """
        Get a user
        https://docs.github.com/rest/reference/users#get-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}"
        response = self._execute("get", url, payload)
        return response

    def list_followers_of_a_user(self, username, payload=None):
        """
        List followers of a user
        https://docs.github.com/rest/reference/users#list-followers-of-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/followers"
        response = self._execute("get", url, payload)
        return response

    def list_the_people_a_user_follows(self, username, payload=None):
        """
        List the people a user follows
        https://docs.github.com/rest/reference/users#list-the-people-a-user-follows
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/following"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_user_follows_another_user(self, username, target_user, payload=None):
        """
        Check if a user follows another user
        https://docs.github.com/rest/reference/users#check-if-a-user-follows-another-user
        Attributes:
        Path Parameters:
        username
        target_user
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}/following/{target_user}"
        response = self._execute("get", url, payload)
        return response

    def list_gpg_keys_for_a_user(self, username, payload=None):
        """
        List GPG keys for a user
        https://docs.github.com/rest/reference/users#list-gpg-keys-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/gpg_keys"
        response = self._execute("get", url, payload)
        return response

    def get_contextual_information_for_a_user(self, username, payload=None):
        """
        Get contextual information for a user
        https://docs.github.com/rest/reference/users#get-contextual-information-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        subject_type
         subject_id
        """
        url = self._base_url + f"/users/{username}/hovercard"
        response = self._execute("get", url, payload)
        return response

    def list_public_keys_for_a_user(self, username, payload=None):
        """
        List public keys for a user
        https://docs.github.com/rest/reference/users#list-public-keys-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/keys"
        response = self._execute("get", url, payload)
        return response



"""
Move projects to or from GitHub.
"""


class Migrations:
    # pylint: disable=too-many-public-methods
    """
    Move projects to or from GitHub.
    """

    def __init__(self, client):
        """
        Initialize the Migrations class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organization_migrations(self, org, payload=None):
        """
        List organization migrations
        https://docs.github.com/rest/reference/migrations#list-organization-migrations
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
         exclude
        """
        url = self._base_url + f"/orgs/{org}/migrations"
        response = self._execute("get", url, payload)
        return response

    def start_an_organization_migration(self, org, payload=None):
        """
        Start an organization migration
        https://docs.github.com/rest/reference/migrations#start-an-organization-migration
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/migrations"
        response = self._execute("post", url, payload)
        return response

    def get_an_organization_migration_status(self, org, migration_id, payload=None):
        """
        Get an organization migration status
        https://docs.github.com/rest/reference/migrations#get-an-organization-migration-status
        Attributes:
        Path Parameters:
        org
        migration_id
        Payload Parameters:
        exclude
        """
        url = self._base_url + f"/orgs/{org}/migrations/{migration_id}"
        response = self._execute("get", url, payload)
        return response

    def download_an_organization_migration_archive(self, org, migration_id, payload=None):
        """
        Download an organization migration archive
        https://docs.github.com/rest/reference/migrations#download-an-organization-migration-archive
        Attributes:
        Path Parameters:
        org
        migration_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/archive"
        response = self._execute("get", url, payload)
        return response

    def delete_an_organization_migration_archive(self, org, migration_id, payload=None):
        """
        Delete an organization migration archive
        https://docs.github.com/rest/reference/migrations#delete-an-organization-migration-archive
        Attributes:
        Path Parameters:
        org
        migration_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/archive"
        response = self._execute("delete", url, payload)
        return response

    def unlock_an_organization_repository(self, org, migration_id, repo_name, payload=None):
        """
        Unlock an organization repository
        https://docs.github.com/rest/reference/migrations#unlock-an-organization-repository
        Attributes:
        Path Parameters:
        org
        migration_id
        repo_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/repos/{repo_name}/lock"
        response = self._execute("delete", url, payload)
        return response

    def list_repositories_in_an_organization_migration(self, org, migration_id, payload=None):
        """
        List repositories in an organization migration
        https://docs.github.com/rest/reference/migrations#list-repositories-in-an-organization-migration
        Attributes:
        Path Parameters:
        org
        migration_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/migrations/{migration_id}/repositories"
        response = self._execute("get", url, payload)
        return response

    def get_an_import_status(self, owner, repo, payload=None):
        """
        Get an import status
        https://docs.github.com/rest/reference/migrations#get-an-import-status
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import"
        response = self._execute("get", url, payload)
        return response

    def start_an_import(self, owner, repo, payload=None):
        """
        Start an import
        https://docs.github.com/rest/reference/migrations#start-an-import
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import"
        response = self._execute("put", url, payload)
        return response

    def update_an_import(self, owner, repo, payload=None):
        """
        Update an import
        https://docs.github.com/rest/reference/migrations#update-an-import
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import"
        response = self._execute("patch", url, payload)
        return response

    def cancel_an_import(self, owner, repo, payload=None):
        """
        Cancel an import
        https://docs.github.com/rest/reference/migrations#cancel-an-import
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import"
        response = self._execute("delete", url, payload)
        return response

    def get_commit_authors(self, owner, repo, payload=None):
        """
        Get commit authors
        https://docs.github.com/rest/reference/migrations#get-commit-authors
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        since-user
        """
        url = self._base_url + f"/repos/{owner}/{repo}/import/authors"
        response = self._execute("get", url, payload)
        return response

    def map_a_commit_author(self, owner, repo, author_id, payload=None):
        """
        Map a commit author
        https://docs.github.com/rest/reference/migrations#map-a-commit-author
        Attributes:
        Path Parameters:
        owner
        repo
        author_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import/authors/{author_id}"
        response = self._execute("patch", url, payload)
        return response

    def get_large_files(self, owner, repo, payload=None):
        """
        Get large files
        https://docs.github.com/rest/reference/migrations#get-large-files
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import/large_files"
        response = self._execute("get", url, payload)
        return response

    def update_git_lfs_preference(self, owner, repo, payload=None):
        """
        Update Git LFS preference
        https://docs.github.com/rest/reference/migrations#update-git-lfs-preference
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/import/lfs"
        response = self._execute("patch", url, payload)
        return response

    def list_user_migrations(self, payload=None):
        """
        List user migrations
        https://docs.github.com/rest/reference/migrations#list-user-migrations
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/migrations"
        response = self._execute("get", url, payload)
        return response

    def start_a_user_migration(self, payload=None):
        """
        Start a user migration
        https://docs.github.com/rest/reference/migrations#start-a-user-migration
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/user/migrations"
        response = self._execute("post", url, payload)
        return response

    def get_a_user_migration_status(self, migration_id, payload=None):
        """
        Get a user migration status
        https://docs.github.com/rest/reference/migrations#get-a-user-migration-status
        Attributes:
        Path Parameters:
        migration_id
        Payload Parameters:
        exclude
        """
        url = self._base_url + f"/user/migrations/{migration_id}"
        response = self._execute("get", url, payload)
        return response

    def download_a_user_migration_archive(self, migration_id, payload=None):
        """
        Download a user migration archive
        https://docs.github.com/rest/reference/migrations#download-a-user-migration-archive
        Attributes:
        Path Parameters:
        migration_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/migrations/{migration_id}/archive"
        response = self._execute("get", url, payload)
        return response

    def delete_a_user_migration_archive(self, migration_id, payload=None):
        """
        Delete a user migration archive
        https://docs.github.com/rest/reference/migrations#delete-a-user-migration-archive
        Attributes:
        Path Parameters:
        migration_id
        Payload Parameters:

        """
        url = self._base_url + f"/user/migrations/{migration_id}/archive"
        response = self._execute("delete", url, payload)
        return response

    def unlock_a_user_repository(self, migration_id, repo_name, payload=None):
        """
        Unlock a user repository
        https://docs.github.com/rest/reference/migrations#unlock-a-user-repository
        Attributes:
        Path Parameters:
        migration_id
        repo_name
        Payload Parameters:

        """
        url = self._base_url + f"/user/migrations/{migration_id}/repos/{repo_name}/lock"
        response = self._execute("delete", url, payload)
        return response

    def list_repositories_for_a_user_migration(self, migration_id, payload=None):
        """
        List repositories for a user migration
        https://docs.github.com/rest/reference/migrations#list-repositories-for-a-user-migration
        Attributes:
        Path Parameters:
        migration_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/user/migrations/{migration_id}/repositories"
        response = self._execute("get", url, payload)
        return response



"""
Activity APIs provide access to notifications, subscriptions, and timelines.
"""


class Activity:
    # pylint: disable=too-many-public-methods
    """
    Activity APIs provide access to notifications, subscriptions, and timelines.
    """

    def __init__(self, client):
        """
        Initialize the Activity class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_public_events(self, payload=None):
        """
        List public events
        https://docs.github.com/rest/reference/activity#list-public-events
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/events"
        response = self._execute("get", url, payload)
        return response

    def get_feeds(self, payload=None):
        """
        Get feeds
        https://docs.github.com/rest/reference/activity#get-feeds
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/feeds"
        response = self._execute("get", url, payload)
        return response

    def list_public_events_for_a_network_of_repositories(self, owner, repo, payload=None):
        """
        List public events for a network of repositories
        https://docs.github.com/rest/reference/activity#list-public-events-for-a-network-of-repositories
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/networks/{owner}/{repo}/events"
        response = self._execute("get", url, payload)
        return response

    def list_notifications_for_the_authenticated_user(self, payload=None):
        """
        List notifications for the authenticated user
        https://docs.github.com/rest/reference/activity#list-notifications-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        all
         participating
         since
         before
         per-page
         page
        """
        url = self._base_url + "/notifications"
        response = self._execute("get", url, payload)
        return response

    def mark_notifications_as_read(self, payload=None):
        """
        Mark notifications as read
        https://docs.github.com/rest/reference/activity#mark-notifications-as-read
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/notifications"
        response = self._execute("put", url, payload)
        return response

    def get_a_thread(self, thread_id, payload=None):
        """
        Get a thread
        https://docs.github.com/rest/reference/activity#get-a-thread
        Attributes:
        Path Parameters:
        thread_id
        Payload Parameters:

        """
        url = self._base_url + f"/notifications/threads/{thread_id}"
        response = self._execute("get", url, payload)
        return response

    def mark_a_thread_as_read(self, thread_id, payload=None):
        """
        Mark a thread as read
        https://docs.github.com/rest/reference/activity#mark-a-thread-as-read
        Attributes:
        Path Parameters:
        thread_id
        Payload Parameters:

        """
        url = self._base_url + f"/notifications/threads/{thread_id}"
        response = self._execute("patch", url, payload)
        return response

    def get_a_thread_subscription_for_the_authenticated_user(self, thread_id, payload=None):
        """
        Get a thread subscription for the authenticated user
        https://docs.github.com/rest/reference/activity#get-a-thread-subscription-for-the-authenticated-user
        Attributes:
        Path Parameters:
        thread_id
        Payload Parameters:

        """
        url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
        response = self._execute("get", url, payload)
        return response

    def set_a_thread_subscription(self, thread_id, payload=None):
        """
        Set a thread subscription
        https://docs.github.com/rest/reference/activity#set-a-thread-subscription
        Attributes:
        Path Parameters:
        thread_id
        Payload Parameters:

        """
        url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
        response = self._execute("put", url, payload)
        return response

    def delete_a_thread_subscription(self, thread_id, payload=None):
        """
        Delete a thread subscription
        https://docs.github.com/rest/reference/activity#delete-a-thread-subscription
        Attributes:
        Path Parameters:
        thread_id
        Payload Parameters:

        """
        url = self._base_url + f"/notifications/threads/{thread_id}/subscription"
        response = self._execute("delete", url, payload)
        return response

    def list_public_organization_events(self, org, payload=None):
        """
        List public organization events
        https://docs.github.com/rest/reference/activity#list-public-organization-events
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/events"
        response = self._execute("get", url, payload)
        return response

    def list_repository_events(self, owner, repo, payload=None):
        """
        List repository events
        https://docs.github.com/rest/reference/activity#list-repository-events
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/events"
        response = self._execute("get", url, payload)
        return response

    def list_repository_notifications_for_the_authenticated_user(self, owner, repo, payload=None):
        """
        List repository notifications for the authenticated user
        https://docs.github.com/rest/reference/activity#list-repository-notifications-for-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        all
         participating
         since
         before
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/notifications"
        response = self._execute("get", url, payload)
        return response

    def mark_repository_notifications_as_read(self, owner, repo, payload=None):
        """
        Mark repository notifications as read
        https://docs.github.com/rest/reference/activity#mark-repository-notifications-as-read
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/notifications"
        response = self._execute("put", url, payload)
        return response

    def list_stargazers(self, owner, repo, payload=None):
        """
        List stargazers
        https://docs.github.com/rest/reference/activity#list-stargazers
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/stargazers"
        response = self._execute("get", url, payload)
        return response

    def list_watchers(self, owner, repo, payload=None):
        """
        List watchers
        https://docs.github.com/rest/reference/activity#list-watchers
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/subscribers"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_subscription(self, owner, repo, payload=None):
        """
        Get a repository subscription
        https://docs.github.com/rest/reference/activity#get-a-repository-subscription
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/subscription"
        response = self._execute("get", url, payload)
        return response

    def set_a_repository_subscription(self, owner, repo, payload=None):
        """
        Set a repository subscription
        https://docs.github.com/rest/reference/activity#set-a-repository-subscription
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/subscription"
        response = self._execute("put", url, payload)
        return response

    def delete_a_repository_subscription(self, owner, repo, payload=None):
        """
        Delete a repository subscription
        https://docs.github.com/rest/reference/activity#delete-a-repository-subscription
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/subscription"
        response = self._execute("delete", url, payload)
        return response

    def list_repositories_starred_by_the_authenticated_user(self, payload=None):
        """
        List repositories starred by the authenticated user
        https://docs.github.com/rest/reference/activity#list-repositories-starred-by-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        sort
         direction
         per-page
         page
        """
        url = self._base_url + "/user/starred"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_repository_is_starred_by_the_authenticated_user(self, owner, repo, payload=None):
        """
        Check if a repository is starred by the authenticated user
        https://docs.github.com/rest/reference/activity#check-if-a-repository-is-starred-by-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/user/starred/{owner}/{repo}"
        response = self._execute("get", url, payload)
        return response

    def star_a_repository_for_the_authenticated_user(self, owner, repo, payload=None):
        """
        Star a repository for the authenticated user
        https://docs.github.com/rest/reference/activity#star-a-repository-for-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/user/starred/{owner}/{repo}"
        response = self._execute("put", url, payload)
        return response

    def unstar_a_repository_for_the_authenticated_user(self, owner, repo, payload=None):
        """
        Unstar a repository for the authenticated user
        https://docs.github.com/rest/reference/activity#unstar-a-repository-for-the-authenticated-user
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/user/starred/{owner}/{repo}"
        response = self._execute("delete", url, payload)
        return response

    def list_repositories_watched_by_the_authenticated_user(self, payload=None):
        """
        List repositories watched by the authenticated user
        https://docs.github.com/rest/reference/activity#list-repositories-watched-by-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/subscriptions"
        response = self._execute("get", url, payload)
        return response

    def list_events_for_the_authenticated_user(self, username, payload=None):
        """
        List events for the authenticated user
        https://docs.github.com/rest/reference/activity#list-events-for-the-authenticated-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/events"
        response = self._execute("get", url, payload)
        return response

    def list_organization_events_for_the_authenticated_user(self, username, org, payload=None):
        """
        List organization events for the authenticated user
        https://docs.github.com/rest/reference/activity#list-organization-events-for-the-authenticated-user
        Attributes:
        Path Parameters:
        username
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/events/orgs/{org}"
        response = self._execute("get", url, payload)
        return response

    def list_public_events_for_a_user(self, username, payload=None):
        """
        List public events for a user
        https://docs.github.com/rest/reference/activity#list-public-events-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/events/public"
        response = self._execute("get", url, payload)
        return response

    def list_events_received_by_the_authenticated_user(self, username, payload=None):
        """
        List events received by the authenticated user
        https://docs.github.com/rest/reference/activity#list-events-received-by-the-authenticated-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/received_events"
        response = self._execute("get", url, payload)
        return response

    def list_public_events_received_by_a_user(self, username, payload=None):
        """
        List public events received by a user
        https://docs.github.com/rest/reference/activity#list-public-events-received-by-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/received_events/public"
        response = self._execute("get", url, payload)
        return response

    def list_repositories_starred_by_a_user(self, username, payload=None):
        """
        List repositories starred by a user
        https://docs.github.com/rest/reference/activity#list-repositories-starred-by-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        sort
         direction
         per-page
         page
        """
        url = self._base_url + f"/users/{username}/starred"
        response = self._execute("get", url, payload)
        return response

    def list_repositories_watched_by_a_user(self, username, payload=None):
        """
        List repositories watched by a user
        https://docs.github.com/rest/reference/activity#list-repositories-watched-by-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/subscriptions"
        response = self._execute("get", url, payload)
        return response



"""
Look for stuff on GitHub.
"""


class Search:
    """
    Look for stuff on GitHub.
    """

    def __init__(self, client):
        """
        Initialize the Search class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_resources_accessible_to_the_access_tokens_session(self, payload=None):
        """
        List resources accessible to the access_token's session
        https://docs.github.com/rest/reference/blackbird#list-resources-accessible-to-the-current-access-tokens-session
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/internal/blackbird/accessible_resources"
        response = self._execute("post", url, payload)
        return response

    def generate_a_signed_access_token_for_use_with_blackbird_fe(self, payload=None):
        """
        Generate a signed access token for use with blackbird-fe
        https://docs.github.com/rest/reference/blackbird#generate-a-signed-access-token-for-use-with-blackbird-fe
        Attributes:
        Path Parameters:

        Payload Parameters:

        """
        url = self._base_url + "/internal/blackbird/authorize"
        response = self._execute("post", url, payload)
        return response

    def search_code(self, payload=None):
        """
        Search code
        https://docs.github.com/rest/reference/search#search-code
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/code"
        response = self._execute("get", url, payload)
        return response

    def search_commits(self, payload=None):
        """
        Search commits
        https://docs.github.com/rest/reference/search#search-commits
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/commits"
        response = self._execute("get", url, payload)
        return response

    def search_issues_and_pull_requests(self, payload=None):
        """
        Search issues and pull requests
        https://docs.github.com/rest/reference/search#search-issues-and-pull-requests
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/issues"
        response = self._execute("get", url, payload)
        return response

    def search_labels(self, payload=None):
        """
        Search labels
        https://docs.github.com/rest/reference/search#search-labels
        Attributes:
        Path Parameters:

        Payload Parameters:
        repository_id
         q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/labels"
        response = self._execute("get", url, payload)
        return response

    def search_repositories(self, payload=None):
        """
        Search repositories
        https://docs.github.com/rest/reference/search#search-repositories
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/repositories"
        response = self._execute("get", url, payload)
        return response

    def search_topics(self, payload=None):
        """
        Search topics
        https://docs.github.com/rest/reference/search#search-topics
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         per-page
         page
        """
        url = self._base_url + "/search/topics"
        response = self._execute("get", url, payload)
        return response

    def search_users(self, payload=None):
        """
        Search users
        https://docs.github.com/rest/reference/search#search-users
        Attributes:
        Path Parameters:

        Payload Parameters:
        q
         sort
         order
         per-page
         page
        """
        url = self._base_url + "/search/users"
        response = self._execute("get", url, payload)
        return response



"""
Endpoints to manage GitHub Actions using the REST API.
"""
# pylint: disable=too-many-lines


class Actions:
    # pylint: disable=too-many-public-methods
    """
    Endpoints to manage GitHub Actions using the REST API.
    """

    def __init__(self, client):
        """
        Initialize the Actions class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_github_actions_cache_usage_for_an_enterprise(self, enterprise, payload=None):
        """
        Get GitHub Actions cache usage for an enterprise
        https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/cache/usage"
        response = self._execute("get", url, payload)
        return response

    def set_the_github_actions_oidc_custom_issuer_policy_for_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        Set the GitHub Actions OIDC custom issuer policy for an enterprise
        https://docs.github.com/rest/reference/actions/oidc#set-actions-oidc-custom-issuer-policy-for-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/oidc/customization/issuer"
        response = self._execute("put", url, payload)
        return response

    def get_default_workflow_permissions_for_an_enterprise(self, enterprise, payload=None):
        """
        Get default workflow permissions for an enterprise
        https://docs.github.com/rest/reference/actions#get-default-workflow-permissions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/workflow"
        response = self._execute("get", url, payload)
        return response

    def set_default_workflow_permissions_for_an_enterprise(self, enterprise, payload=None):
        """
        Set default workflow permissions for an enterprise
        https://docs.github.com/rest/reference/actions#set-default-workflow-permissions-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/actions/permissions/workflow"
        response = self._execute("put", url, payload)
        return response

    def get_github_actions_cache_usage_for_an_organization(self, org, payload=None):
        """
        Get GitHub Actions cache usage for an organization
        https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/cache/usage"
        response = self._execute("get", url, payload)
        return response

    def list_repositories_with_github_actions_cache_usage_for_an_organization(
        self, org, payload=None
    ):
        """
        List repositories with GitHub Actions cache usage for an organization
        https://docs.github.com/rest/reference/actions#list-repositories-with-github-actions-cache-usage-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/actions/cache/usage-by-repository"
        response = self._execute("get", url, payload)
        return response

    def get_github_actions_permissions_for_an_organization(self, org, payload=None):
        """
        Get GitHub Actions permissions for an organization
        https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions"
        response = self._execute("get", url, payload)
        return response

    def set_github_actions_permissions_for_an_organization(self, org, payload=None):
        """
        Set GitHub Actions permissions for an organization
        https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions"
        response = self._execute("put", url, payload)
        return response

    def list_selected_repositories_enabled_for_github_actions_in_an_organization(
        self, org, payload=None
    ):
        """
        List selected repositories enabled for GitHub Actions in an organization
        https://docs.github.com/rest/reference/actions#list-selected-repositories-enabled-for-github-actions-in-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/repositories"
        response = self._execute("get", url, payload)
        return response

    def set_selected_repositories_enabled_for_github_actions_in_an_organization(
        self, org, payload=None
    ):
        """
        Set selected repositories enabled for GitHub Actions in an organization
        https://docs.github.com/rest/reference/actions#set-selected-repositories-enabled-for-github-actions-in-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/repositories"
        response = self._execute("put", url, payload)
        return response

    def enable_a_selected_repository_for_github_actions_in_an_organization(
        self, org, repository_id, payload=None
    ):
        """
        Enable a selected repository for GitHub Actions in an organization
        https://docs.github.com/rest/reference/actions#enable-a-selected-repository-for-github-actions-in-an-organization
        Attributes:
        Path Parameters:
        org
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/repositories/{repository_id}"
        response = self._execute("put", url, payload)
        return response

    def disable_a_selected_repository_for_github_actions_in_an_organization(
        self, org, repository_id, payload=None
    ):
        """
        Disable a selected repository for GitHub Actions in an organization
        https://docs.github.com/rest/reference/actions#disable-a-selected-repository-for-github-actions-in-an-organization
        Attributes:
        Path Parameters:
        org
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/repositories/{repository_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_allowed_actions_and_reusable_workflows_for_an_organization(self, org, payload=None):
        """
        Get allowed actions and reusable workflows for an organization
        https://docs.github.com/rest/reference/actions#get-allowed-actions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/selected-actions"
        response = self._execute("get", url, payload)
        return response

    def set_allowed_actions_and_reusable_workflows_for_an_organization(self, org, payload=None):
        """
        Set allowed actions and reusable workflows for an organization
        https://docs.github.com/rest/reference/actions#set-allowed-actions-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/selected-actions"
        response = self._execute("put", url, payload)
        return response

    def get_default_workflow_permissions_for_an_organization(self, org, payload=None):
        """
        Get default workflow permissions for an organization
        https://docs.github.com/rest/reference/actions#get-default-workflow-permissions
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/workflow"
        response = self._execute("get", url, payload)
        return response

    def set_default_workflow_permissions_for_an_organization(self, org, payload=None):
        """
        Set default workflow permissions for an organization
        https://docs.github.com/rest/reference/actions#set-default-workflow-permissions
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/permissions/workflow"
        response = self._execute("put", url, payload)
        return response

    def list_self_hosted_runner_groups_for_an_organization(self, org, payload=None):
        """
        List self-hosted runner groups for an organization
        https://docs.github.com/rest/reference/actions#list-self-hosted-runner-groups-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
         visible-to-repository
        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups"
        response = self._execute("get", url, payload)
        return response

    def create_a_self_hosted_runner_group_for_an_organization(self, org, payload=None):
        """
        Create a self-hosted runner group for an organization
        https://docs.github.com/rest/reference/actions#create-a-self-hosted-runner-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups"
        response = self._execute("post", url, payload)
        return response

    def get_a_self_hosted_runner_group_for_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        Get a self-hosted runner group for an organization
        https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}"
        response = self._execute("get", url, payload)
        return response

    def update_a_self_hosted_runner_group_for_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        Update a self-hosted runner group for an organization
        https://docs.github.com/rest/reference/actions#update-a-self-hosted-runner-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_a_self_hosted_runner_group_from_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        Delete a self-hosted runner group from an organization
        https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-group-from-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_repository_access_to_a_self_hosted_runner_group_in_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        List repository access to a self-hosted runner group in an organization
        https://docs.github.com/rest/reference/actions#list-repository-access-to-a-self-hosted-runner-group-in-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/repositories"
        response = self._execute("get", url, payload)
        return response

    def set_repository_access_for_a_self_hosted_runner_group_in_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        Set repository access for a self-hosted runner group in an organization
        https://docs.github.com/rest/reference/actions#set-repository-access-to-a-self-hosted-runner-group-in-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/repositories"
        response = self._execute("put", url, payload)
        return response

    def add_repository_access_to_a_self_hosted_runner_group_in_an_organization(
        self, org, runner_group_id, repository_id, payload=None
    ):
        """
        Add repository access to a self-hosted runner group in an organization
        https://docs.github.com/rest/reference/actions#add-repository-acess-to-a-self-hosted-runner-group-in-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/repositories/{repository_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_repository_access_to_a_self_hosted_runner_group_in_an_organization(
        self, org, runner_group_id, repository_id, payload=None
    ):
        """
        Remove repository access to a self-hosted runner group in an organization
        https://docs.github.com/rest/reference/actions#remove-repository-access-to-a-self-hosted-runner-group-in-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/repositories/{repository_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_self_hosted_runners_in_a_group_for_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        List self-hosted runners in a group for an organization
        https://docs.github.com/rest/reference/actions#list-self-hosted-runners-in-a-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/runners"
        response = self._execute("get", url, payload)
        return response

    def set_self_hosted_runners_in_a_group_for_an_organization(
        self, org, runner_group_id, payload=None
    ):
        """
        Set self-hosted runners in a group for an organization
        https://docs.github.com/rest/reference/actions#set-self-hosted-runners-in-a-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/runners"
        response = self._execute("put", url, payload)
        return response

    def add_a_self_hosted_runner_to_a_group_for_an_organization(
        self, org, runner_group_id, runner_id, payload=None
    ):
        """
        Add a self-hosted runner to a group for an organization
        https://docs.github.com/rest/reference/actions#add-a-self-hosted-runner-to-a-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        runner_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_a_self_hosted_runner_from_a_group_for_an_organization(
        self, org, runner_group_id, runner_id, payload=None
    ):
        """
        Remove a self-hosted runner from a group for an organization
        https://docs.github.com/rest/reference/actions#remove-a-self-hosted-runner-from-a-group-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_group_id
        runner_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/runner-groups/{runner_group_id}/runners/{runner_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_self_hosted_runners_for_an_organization(self, org, payload=None):
        """
        List self-hosted runners for an organization
        https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/actions/runners"
        response = self._execute("get", url, payload)
        return response

    def list_runner_applications_for_an_organization(self, org, payload=None):
        """
        List runner applications for an organization
        https://docs.github.com/rest/reference/actions#list-runner-applications-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/downloads"
        response = self._execute("get", url, payload)
        return response

    def create_a_registration_token_for_an_organization(self, org, payload=None):
        """
        Create a registration token for an organization
        https://docs.github.com/rest/reference/actions#create-a-registration-token-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/registration-token"
        response = self._execute("post", url, payload)
        return response

    def create_a_remove_token_for_an_organization(self, org, payload=None):
        """
        Create a remove token for an organization
        https://docs.github.com/rest/reference/actions#create-a-remove-token-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/remove-token"
        response = self._execute("post", url, payload)
        return response

    def get_a_self_hosted_runner_for_an_organization(self, org, runner_id, payload=None):
        """
        Get a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_self_hosted_runner_from_an_organization(self, org, runner_id, payload=None):
        """
        Delete a self-hosted runner from an organization
        https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-from-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_labels_for_a_self_hosted_runner_for_an_organization(
        self, org, runner_id, payload=None
    ):
        """
        List labels for a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}/labels"
        response = self._execute("get", url, payload)
        return response

    def add_custom_labels_to_a_self_hosted_runner_for_an_organization(
        self, org, runner_id, payload=None
    ):
        """
        Add custom labels to a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}/labels"
        response = self._execute("post", url, payload)
        return response

    def set_custom_labels_for_a_self_hosted_runner_for_an_organization(
        self, org, runner_id, payload=None
    ):
        """
        Set custom labels for a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}/labels"
        response = self._execute("put", url, payload)
        return response

    def remove_all_custom_labels_from_a_self_hosted_runner_for_an_organization(
        self, org, runner_id, payload=None
    ):
        """
        Remove all custom labels from a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}/labels"
        response = self._execute("delete", url, payload)
        return response

    def remove_a_custom_label_from_a_self_hosted_runner_for_an_organization(
        self, org, runner_id, name, payload=None
    ):
        """
        Remove a custom label from a self-hosted runner for an organization
        https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-an-organization
        Attributes:
        Path Parameters:
        org
        runner_id
        name
        Payload Parameters:
        runner-label-name
        """
        url = self._base_url + f"/orgs/{org}/actions/runners/{runner_id}/labels/{name}"
        response = self._execute("delete", url, payload)
        return response

    def list_organization_secrets(self, org, payload=None):
        """
        List organization secrets
        https://docs.github.com/rest/reference/actions#list-organization-secrets
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/actions/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_public_key(self, org, payload=None):
        """
        Get an organization public key
        https://docs.github.com/rest/reference/actions#get-an-organization-public-key
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_secret(self, org, secret_name, payload=None):
        """
        Get an organization secret
        https://docs.github.com/rest/reference/actions#get-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_an_organization_secret(self, org, secret_name, payload=None):
        """
        Create or update an organization secret
        https://docs.github.com/rest/reference/actions#create-or-update-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_an_organization_secret(self, org, secret_name, payload=None):
        """
        Delete an organization secret
        https://docs.github.com/rest/reference/actions#delete-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response

    def list_selected_repositories_for_an_organization_secret(self, org, secret_name, payload=None):
        """
        List selected repositories for an organization secret
        https://docs.github.com/rest/reference/actions#list-selected-repositories-for-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:
        page
         per-page
        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/{secret_name}/repositories"
        response = self._execute("get", url, payload)
        return response

    def set_selected_repositories_for_an_organization_secret(self, org, secret_name, payload=None):
        """
        Set selected repositories for an organization secret
        https://docs.github.com/rest/reference/actions#set-selected-repositories-for-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/actions/secrets/{secret_name}/repositories"
        response = self._execute("put", url, payload)
        return response

    def add_selected_repository_to_an_organization_secret(
        self, org, secret_name, repository_id, payload=None
    ):
        """
        Add selected repository to an organization secret
        https://docs.github.com/rest/reference/actions#add-selected-repository-to-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("put", url, payload)
        return response

    def remove_selected_repository_from_an_organization_secret(
        self, org, secret_name, repository_id, payload=None
    ):
        """
        Remove selected repository from an organization secret
        https://docs.github.com/rest/reference/actions#remove-selected-repository-from-an-organization-secret
        Attributes:
        Path Parameters:
        org
        secret_name
        repository_id
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/orgs/{org}/actions/secrets/{secret_name}/repositories/{repository_id}"
        )
        response = self._execute("delete", url, payload)
        return response

    def list_artifacts_for_a_repository(self, owner, repo, payload=None):
        """
        List artifacts for a repository
        https://docs.github.com/rest/reference/actions#list-artifacts-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/artifacts"
        response = self._execute("get", url, payload)
        return response

    def get_an_artifact(self, owner, repo, artifact_id, payload=None):
        """
        Get an artifact
        https://docs.github.com/rest/reference/actions#get-an-artifact
        Attributes:
        Path Parameters:
        owner
        repo
        artifact_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/artifacts/{artifact_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_an_artifact(self, owner, repo, artifact_id, payload=None):
        """
        Delete an artifact
        https://docs.github.com/rest/reference/actions#delete-an-artifact
        Attributes:
        Path Parameters:
        owner
        repo
        artifact_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/artifacts/{artifact_id}"
        response = self._execute("delete", url, payload)
        return response

    def download_an_artifact(
        self, owner, repo, artifact_id, archive_format, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Download an artifact
        https://docs.github.com/rest/reference/actions#download-an-artifact
        Attributes:
        Path Parameters:
        owner
        repo
        artifact_id
        archive_format
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/actions/artifacts/{artifact_id}/{archive_format}"
        )
        response = self._execute("get", url, payload)
        return response

    def get_github_actions_cache_usage_for_a_repository(self, owner, repo, payload=None):
        """
        Get GitHub Actions cache usage for a repository
        https://docs.github.com/rest/reference/actions#get-github-actions-cache-usage-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/cache/usage"
        response = self._execute("get", url, payload)
        return response

    def list_github_actions_caches_for_a_repository(self, owner, repo, payload=None):
        """
        List GitHub Actions caches for a repository
        https://docs.github.com/rest/actions/cache#list-github-actions-caches-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
         git-ref
         actions-cache-key
         actions-cache-list-sort
         direction
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/caches"
        response = self._execute("get", url, payload)
        return response

    def delete_github_actions_caches_for_a_repository__using_a_cache_key(
        self, owner, repo, payload=None
    ):
        """
        Delete GitHub Actions caches for a repository (using a cache key)
        https://docs.github.com/rest/actions/cache#delete-github-actions-caches-for-a-repository-using-a-cache-key
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        actions-cache-key-required
         git-ref
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/caches"
        response = self._execute("delete", url, payload)
        return response

    def delete_a_github_actions_cache_for_a_repository__using_a_cache_id(
        self, owner, repo, cache_id, payload=None
    ):
        """
        Delete a GitHub Actions cache for a repository (using a cache ID)
        https://docs.github.com/rest/actions/cache#delete-a-github-actions-cache-for-a-repository-using-a-cache-id
        Attributes:
        Path Parameters:
        owner
        repo
        cache_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/caches/{cache_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_a_job_for_a_workflow_run(self, owner, repo, job_id, payload=None):
        """
        Get a job for a workflow run
        https://docs.github.com/rest/reference/actions#get-a-job-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        job_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/jobs/{job_id}"
        response = self._execute("get", url, payload)
        return response

    def download_job_logs_for_a_workflow_run(self, owner, repo, job_id, payload=None):
        """
        Download job logs for a workflow run
        https://docs.github.com/rest/reference/actions#download-job-logs-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        job_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/jobs/{job_id}/logs"
        response = self._execute("get", url, payload)
        return response

    def re_run_a_job_from_a_workflow_run(self, owner, repo, job_id, payload=None):
        """
        Re-run a job from a workflow run
        https://docs.github.com/rest/reference/actions#re-run-job-for-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        job_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/jobs/{job_id}/rerun"
        response = self._execute("post", url, payload)
        return response

    def get_the_opt_out_flag_of_an_oidc_subject_claim_customization_for_a_repository(
        self, owner, repo, payload=None
    ):
        """
        Get the opt-out flag of an OIDC subject claim customization for a repository
        https://docs.github.com/rest/actions/oidc#get-the-opt-out-flag-of-an-oidc-subject-claim-customization-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/oidc/customization/sub"
        response = self._execute("get", url, payload)
        return response

    def set_the_opt_out_flag_of_an_oidc_subject_claim_customization_for_a_repository(
        self, owner, repo, payload=None
    ):
        """
        Set the opt-out flag of an OIDC subject claim customization for a repository
        https://docs.github.com/rest/actions/oidc#set-the-opt-out-flag-of-an-oidc-subject-claim-customization-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/oidc/customization/sub"
        response = self._execute("put", url, payload)
        return response

    def get_github_actions_permissions_for_a_repository(self, owner, repo, payload=None):
        """
        Get GitHub Actions permissions for a repository
        https://docs.github.com/rest/reference/actions#get-github-actions-permissions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions"
        response = self._execute("get", url, payload)
        return response

    def set_github_actions_permissions_for_a_repository(self, owner, repo, payload=None):
        """
        Set GitHub Actions permissions for a repository
        https://docs.github.com/rest/reference/actions#set-github-actions-permissions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions"
        response = self._execute("put", url, payload)
        return response

    def get_the_level_of_access_for_workflows_outside_of_the_repository(
        self, owner, repo, payload=None
    ):
        """
        Get the level of access for workflows outside of the repository
        https://docs.github.com/rest/reference/actions#get-workflow-access-level-to-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/access"
        response = self._execute("get", url, payload)
        return response

    def set_the_level_of_access_for_workflows_outside_of_the_repository(
        self, owner, repo, payload=None
    ):
        """
        Set the level of access for workflows outside of the repository
        https://docs.github.com/rest/reference/actions#set-workflow-access-to-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/access"
        response = self._execute("put", url, payload)
        return response

    def get_allowed_actions_and_reusable_workflows_for_a_repository(
        self, owner, repo, payload=None
    ):
        """
        Get allowed actions and reusable workflows for a repository
        https://docs.github.com/rest/reference/actions#get-allowed-actions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/selected-actions"
        response = self._execute("get", url, payload)
        return response

    def set_allowed_actions_and_reusable_workflows_for_a_repository(
        self, owner, repo, payload=None
    ):
        """
        Set allowed actions and reusable workflows for a repository
        https://docs.github.com/rest/reference/actions#set-allowed-actions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/selected-actions"
        response = self._execute("put", url, payload)
        return response

    def get_default_workflow_permissions_for_a_repository(self, owner, repo, payload=None):
        """
        Get default workflow permissions for a repository
        https://docs.github.com/rest/reference/actions#get-default-workflow-permissions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/workflow"
        response = self._execute("get", url, payload)
        return response

    def set_default_workflow_permissions_for_a_repository(self, owner, repo, payload=None):
        """
        Set default workflow permissions for a repository
        https://docs.github.com/rest/reference/actions#set-default-workflow-permissions-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/permissions/workflow"
        response = self._execute("put", url, payload)
        return response

    def list_self_hosted_runners_for_a_repository(self, owner, repo, payload=None):
        """
        List self-hosted runners for a repository
        https://docs.github.com/rest/reference/actions#list-self-hosted-runners-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners"
        response = self._execute("get", url, payload)
        return response

    def list_runner_applications_for_a_repository(self, owner, repo, payload=None):
        """
        List runner applications for a repository
        https://docs.github.com/rest/reference/actions#list-runner-applications-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/downloads"
        response = self._execute("get", url, payload)
        return response

    def create_a_registration_token_for_a_repository(self, owner, repo, payload=None):
        """
        Create a registration token for a repository
        https://docs.github.com/rest/reference/actions#create-a-registration-token-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/registration-token"
        response = self._execute("post", url, payload)
        return response

    def create_a_remove_token_for_a_repository(self, owner, repo, payload=None):
        """
        Create a remove token for a repository
        https://docs.github.com/rest/reference/actions#create-a-remove-token-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/remove-token"
        response = self._execute("post", url, payload)
        return response

    def get_a_self_hosted_runner_for_a_repository(self, owner, repo, runner_id, payload=None):
        """
        Get a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#get-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_self_hosted_runner_from_a_repository(self, owner, repo, runner_id, payload=None):
        """
        Delete a self-hosted runner from a repository
        https://docs.github.com/rest/reference/actions#delete-a-self-hosted-runner-from-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_labels_for_a_self_hosted_runner_for_a_repository(
        self, owner, repo, runner_id, payload=None
    ):
        """
        List labels for a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#list-labels-for-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}/labels"
        response = self._execute("get", url, payload)
        return response

    def add_custom_labels_to_a_self_hosted_runner_for_a_repository(
        self, owner, repo, runner_id, payload=None
    ):
        """
        Add custom labels to a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#add-custom-labels-to-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}/labels"
        response = self._execute("post", url, payload)
        return response

    def set_custom_labels_for_a_self_hosted_runner_for_a_repository(
        self, owner, repo, runner_id, payload=None
    ):
        """
        Set custom labels for a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#set-custom-labels-for-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}/labels"
        response = self._execute("put", url, payload)
        return response

    def remove_all_custom_labels_from_a_self_hosted_runner_for_a_repository(
        self, owner, repo, runner_id, payload=None
    ):
        """
        Remove all custom labels from a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#remove-all-custom-labels-from-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}/labels"
        response = self._execute("delete", url, payload)
        return response

    def remove_a_custom_label_from_a_self_hosted_runner_for_a_repository(
        self, owner, repo, runner_id, name, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Remove a custom label from a self-hosted runner for a repository
        https://docs.github.com/rest/reference/actions#remove-a-custom-label-from-a-self-hosted-runner-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        runner_id
        name
        Payload Parameters:
        runner-label-name
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runners/{runner_id}/labels/{name}"
        response = self._execute("delete", url, payload)
        return response

    def list_workflow_runs_for_a_repository(self, owner, repo, payload=None):
        """
        List workflow runs for a repository
        https://docs.github.com/rest/reference/actions#list-workflow-runs-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        actor
         workflow-run-branch
         event
         workflow-run-status
         per-page
         page
         created
         exclude-pull-requests
         workflow-run-check-suite-id
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs"
        response = self._execute("get", url, payload)
        return response

    def get_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Get a workflow run
        https://docs.github.com/rest/reference/actions#get-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:
        exclude-pull-requests
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}"
        response = self._execute("get", url, payload)
        return response

    def delete_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Delete a workflow run
        https://docs.github.com/rest/reference/actions#delete-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_the_review_history_for_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Get the review history for a workflow run
        https://docs.github.com/rest/reference/actions#get-the-review-history-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/approvals"
        response = self._execute("get", url, payload)
        return response

    def approve_a_workflow_run_for_a_fork_pull_request(self, owner, repo, run_id, payload=None):
        """
        Approve a workflow run for a fork pull request
        https://docs.github.com/rest/reference/actions#approve-a-workflow-run-for-a-fork-pull-request
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/approve"
        response = self._execute("post", url, payload)
        return response

    def list_workflow_run_artifacts(self, owner, repo, run_id, payload=None):
        """
        List workflow run artifacts
        https://docs.github.com/rest/reference/actions#list-workflow-run-artifacts
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/artifacts"
        response = self._execute("get", url, payload)
        return response

    def get_a_workflow_run_attempt(
        self, owner, repo, run_id, attempt_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Get a workflow run attempt
        https://docs.github.com/rest/reference/actions#get-a-workflow-run-attempt
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        attempt_number
        Payload Parameters:
        exclude-pull-requests
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/actions/runs/{run_id}/attempts/{attempt_number}"
        )
        response = self._execute("get", url, payload)
        return response

    def list_jobs_for_a_workflow_run_attempt(
        self, owner, repo, run_id, attempt_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        List jobs for a workflow run attempt
        https://docs.github.com/rest/reference/actions#list-jobs-for-a-workflow-run-attempt
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        attempt_number
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/actions/runs/{run_id}/attempts/{attempt_number}/jobs"
        )
        response = self._execute("get", url, payload)
        return response

    def download_workflow_run_attempt_logs(
        self, owner, repo, run_id, attempt_number, payload=None
    ):  # pylint: disable=too-many-arguments
        """
        Download workflow run attempt logs
        https://docs.github.com/rest/reference/actions#download-workflow-run-attempt-logs
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        attempt_number
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repos/{owner}/{repo}/actions/runs/{run_id}/attempts/{attempt_number}/logs"
        )
        response = self._execute("get", url, payload)
        return response

    def cancel_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Cancel a workflow run
        https://docs.github.com/rest/reference/actions#cancel-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/cancel"
        response = self._execute("post", url, payload)
        return response

    def list_jobs_for_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        List jobs for a workflow run
        https://docs.github.com/rest/reference/actions#list-jobs-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:
        filter
         per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/jobs"
        response = self._execute("get", url, payload)
        return response

    def download_workflow_run_logs(self, owner, repo, run_id, payload=None):
        """
        Download workflow run logs
        https://docs.github.com/rest/reference/actions#download-workflow-run-logs
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/logs"
        response = self._execute("get", url, payload)
        return response

    def delete_workflow_run_logs(self, owner, repo, run_id, payload=None):
        """
        Delete workflow run logs
        https://docs.github.com/rest/reference/actions#delete-workflow-run-logs
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/logs"
        response = self._execute("delete", url, payload)
        return response

    def get_pending_deployments_for_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Get pending deployments for a workflow run
        https://docs.github.com/rest/reference/actions#get-pending-deployments-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/pending_deployments"
        response = self._execute("get", url, payload)
        return response

    def review_pending_deployments_for_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Review pending deployments for a workflow run
        https://docs.github.com/rest/reference/actions#review-pending-deployments-for-a-workflow-run
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/pending_deployments"
        response = self._execute("post", url, payload)
        return response

    def re_run_a_workflow(self, owner, repo, run_id, payload=None):
        """
        Re-run a workflow
        https://docs.github.com/rest/reference/actions#re-run-a-workflow
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/rerun"
        response = self._execute("post", url, payload)
        return response

    def re_run_failed_jobs_from_a_workflow_run(self, owner, repo, run_id, payload=None):
        """
        Re-run failed jobs from a workflow run
        https://docs.github.com/rest/reference/actions#re-run-workflow-failed-jobs
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/rerun-failed-jobs"
        response = self._execute("post", url, payload)
        return response

    def retry_a_workflow(self, owner, repo, run_id, payload=None):
        """
        Retry a workflow
        https://docs.github.com/rest/reference/actions#retry-a-workflow
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/retry"
        response = self._execute("post", url, payload)
        return response

    def get_workflow_run_usage(self, owner, repo, run_id, payload=None):
        """
        Get workflow run usage
        https://docs.github.com/rest/reference/actions#get-workflow-run-usage
        Attributes:
        Path Parameters:
        owner
        repo
        run_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/runs/{run_id}/timing"
        response = self._execute("get", url, payload)
        return response

    def list_repository_secrets(self, owner, repo, payload=None):
        """
        List repository secrets
        https://docs.github.com/rest/reference/actions#list-repository-secrets
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/secrets"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_public_key(self, owner, repo, payload=None):
        """
        Get a repository public key
        https://docs.github.com/rest/reference/actions#get-a-repository-public-key
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/secrets/public-key"
        response = self._execute("get", url, payload)
        return response

    def get_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Get a repository secret
        https://docs.github.com/rest/reference/actions#get-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/secrets/{secret_name}"
        response = self._execute("get", url, payload)
        return response

    def create_or_update_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Create or update a repository secret
        https://docs.github.com/rest/reference/actions#create-or-update-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/secrets/{secret_name}"
        response = self._execute("put", url, payload)
        return response

    def delete_a_repository_secret(self, owner, repo, secret_name, payload=None):
        """
        Delete a repository secret
        https://docs.github.com/rest/reference/actions#delete-a-repository-secret
        Attributes:
        Path Parameters:
        owner
        repo
        secret_name
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/secrets/{secret_name}"
        response = self._execute("delete", url, payload)
        return response

    def list_repository_workflows(self, owner, repo, payload=None):
        """
        List repository workflows
        https://docs.github.com/rest/reference/actions#list-repository-workflows
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows"
        response = self._execute("get", url, payload)
        return response

    def get_a_workflow(self, owner, repo, workflow_id, payload=None):
        """
        Get a workflow
        https://docs.github.com/rest/reference/actions#get-a-workflow
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}"
        response = self._execute("get", url, payload)
        return response

    def disable_a_workflow(self, owner, repo, workflow_id, payload=None):
        """
        Disable a workflow
        https://docs.github.com/rest/reference/actions#disable-a-workflow
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}/disable"
        response = self._execute("put", url, payload)
        return response

    def create_a_workflow_dispatch_event(self, owner, repo, workflow_id, payload=None):
        """
        Create a workflow dispatch event
        https://docs.github.com/rest/reference/actions#create-a-workflow-dispatch-event
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}/dispatches"
        response = self._execute("post", url, payload)
        return response

    def enable_a_workflow(self, owner, repo, workflow_id, payload=None):
        """
        Enable a workflow
        https://docs.github.com/rest/reference/actions#enable-a-workflow
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}/enable"
        response = self._execute("put", url, payload)
        return response

    def list_workflow_runs(self, owner, repo, workflow_id, payload=None):
        """
        List workflow runs
        https://docs.github.com/rest/reference/actions#list-workflow-runs
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:
        actor
         workflow-run-branch
         event
         workflow-run-status
         per-page
         page
         created
         exclude-pull-requests
         workflow-run-check-suite-id
        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}/runs"
        response = self._execute("get", url, payload)
        return response

    def get_workflow_usage(self, owner, repo, workflow_id, payload=None):
        """
        Get workflow usage
        https://docs.github.com/rest/reference/actions#get-workflow-usage
        Attributes:
        Path Parameters:
        owner
        repo
        workflow_id
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/actions/workflows/{workflow_id}/timing"
        response = self._execute("get", url, payload)
        return response

    def run_an_actions_workflow_dynamically(self, repository_id, payload=None):
        """
        Run an actions workflow dynamically
        https://docs.github.com/rest/reference/actions#run-an-actions-workflow-dynamically
        Attributes:
        Path Parameters:
        repository_id
        Payload Parameters:

        """
        url = self._base_url + f"/repositories/{repository_id}/actions/dynamic"
        response = self._execute("post", url, payload)
        return response

    def list_environment_secrets(self, repository_id, environment_name, payload=None):
        """
        List environment secrets
        https://docs.github.com/rest/reference/actions#list-environment-secrets
        Attributes:
        Path Parameters:
        repository_id
        environment_name
        Payload Parameters:
        per-page
         page
        """
        url = (
            self._base_url
            + f"/repositories/{repository_id}/environments/{environment_name}/secrets"
        )
        response = self._execute("get", url, payload)
        return response

    def get_an_environment_public_key(self, repository_id, environment_name, payload=None):
        """
        Get an environment public key
        https://docs.github.com/rest/reference/actions#get-an-environment-public-key
        Attributes:
        Path Parameters:
        repository_id
        environment_name
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repositories/{repository_id}/environments/{environment_name}/secrets/public-key"
        )
        response = self._execute("get", url, payload)
        return response

    def get_an_environment_secret(self, repository_id, environment_name, secret_name, payload=None):
        """
        Get an environment secret
        https://docs.github.com/rest/reference/actions#get-an-environment-secret
        Attributes:
        Path Parameters:
        repository_id
        environment_name
        secret_name
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repositories/{repository_id}/environments/{environment_name}/secrets/{secret_name}"
        )
        response = self._execute("get", url, payload)
        return response

    def create_or_update_an_environment_secret(
        self, repository_id, environment_name, secret_name, payload=None
    ):
        """
        Create or update an environment secret
        https://docs.github.com/rest/reference/actions#create-or-update-an-environment-secret
        Attributes:
        Path Parameters:
        repository_id
        environment_name
        secret_name
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repositories/{repository_id}/environments/{environment_name}/secrets/{secret_name}"
        )
        response = self._execute("put", url, payload)
        return response

    def delete_an_environment_secret(
        self, repository_id, environment_name, secret_name, payload=None
    ):
        """
        Delete an environment secret
        https://docs.github.com/rest/reference/actions#delete-an-environment-secret
        Attributes:
        Path Parameters:
        repository_id
        environment_name
        secret_name
        Payload Parameters:

        """
        url = (
            self._base_url
            + f"/repositories/{repository_id}/environments/{environment_name}/secrets/{secret_name}"
        )
        response = self._execute("delete", url, payload)
        return response



"""
This module is used to make mutations through the GitHub GraphQL API.
"""


class GraphMutation:
    """
    This class is used to make mutations through the GitHub GraphQL API.
    """

    def __init__(self, client):
        """
        Initialize the GraphMutation class.
        """
        self._execute = client._execute
        self._load_query = client._load_query

    def add_enterprise_org(self, organization):
        """
        This module adds an Enterprise organization to the GitHub Enterprise.

        Attributes:
            organization (str): The name of the Organization.
        """
        params = {"organization": organization}
        query = self._load_query("gql_files/create-enterprise-org.gql")
        result = self._execute(query, params)
        return print(result)

    def add_repository(self, repository):
        """
        This module adds a repository to the GitHub Enterprise.

        Attributes:
            repository (str): The name of the Repository.
        """
        params = {"repository": repository}
        query = self._load_query("gql_files/create-repository.gql")
        result = self._execute(query, params)
        return print(result)



"""
Monitor charges and usage from Actions and Packages.
"""


class Billing:
    """
    Monitor charges and usage from Actions and Packages.
    """

    def __init__(self, client):
        """
        Initialize the Billing class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_github_actions_billing_for_an_enterprise(self, enterprise, payload=None):
        """
        Get GitHub Actions billing for an enterprise
        https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/actions"
        response = self._execute("get", url, payload)
        return response

    def get_github_advanced_security_active_committers_for_an_enterprise(
        self, enterprise, payload=None
    ):
        """
        Get GitHub Advanced Security active committers for an enterprise
        https://docs.github.com/rest/reference/billing#export-advanced-security-active-committers-data-for-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/advanced-security"
        response = self._execute("get", url, payload)
        return response

    def get_github_packages_billing_for_an_enterprise(self, enterprise, payload=None):
        """
        Get GitHub Packages billing for an enterprise
        https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/packages"
        response = self._execute("get", url, payload)
        return response

    def get_shared_storage_billing_for_an_enterprise(self, enterprise, payload=None):
        """
        Get shared storage billing for an enterprise
        https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-enterprise
        Attributes:
        Path Parameters:
        enterprise
        Payload Parameters:

        """
        url = self._base_url + f"/enterprises/{enterprise}/settings/billing/shared-storage"
        response = self._execute("get", url, payload)
        return response

    def get_github_actions_billing_for_an_organization(self, org, payload=None):
        """
        Get GitHub Actions billing for an organization
        https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/settings/billing/actions"
        response = self._execute("get", url, payload)
        return response

    def get_github_advanced_security_active_committers_for_an_organization(self, org, payload=None):
        """
        Get GitHub Advanced Security active committers for an organization
        https://docs.github.com/rest/reference/billing#get-github-advanced-security-active-committers-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/settings/billing/advanced-security"
        response = self._execute("get", url, payload)
        return response

    def get_github_packages_billing_for_an_organization(self, org, payload=None):
        """
        Get GitHub Packages billing for an organization
        https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/settings/billing/packages"
        response = self._execute("get", url, payload)
        return response

    def get_shared_storage_billing_for_an_organization(self, org, payload=None):
        """
        Get shared storage billing for an organization
        https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/settings/billing/shared-storage"
        response = self._execute("get", url, payload)
        return response

    def get_github_actions_billing_for_a_user(self, username, payload=None):
        """
        Get GitHub Actions billing for a user
        https://docs.github.com/rest/reference/billing#get-github-actions-billing-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}/settings/billing/actions"
        response = self._execute("get", url, payload)
        return response

    def get_github_packages_billing_for_a_user(self, username, payload=None):
        """
        Get GitHub Packages billing for a user
        https://docs.github.com/rest/reference/billing#get-github-packages-billing-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}/settings/billing/packages"
        response = self._execute("get", url, payload)
        return response

    def get_shared_storage_billing_for_a_user(self, username, payload=None):
        """
        Get shared storage billing for a user
        https://docs.github.com/rest/reference/billing#get-shared-storage-billing-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:

        """
        url = self._base_url + f"/users/{username}/settings/billing/shared-storage"
        response = self._execute("get", url, payload)
        return response



"""
GHES statistics
"""


class ServerStatistics:
    # pylint: disable=too-few-public-methods
    """
    GHES statistics
    """

    def __init__(self, client):
        """
        Initialize the ServerStatistics class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_github_enterprise_server_statistics(self, enterprise_or_org, payload=None):
        """
        Get GitHub Enterprise Server statistics
        https://docs.github.com/rest/reference/enterprise-admin#get-github-enterprise-server-statistics
        Attributes:
        Path Parameters:
        enterprise_or_org
        Payload Parameters:
        date_start
         date_end
        """
        url = self._base_url + f"/enterprise-installation/{enterprise_or_org}/server-statistics"
        response = self._execute("get", url, payload)
        return response



"""
Interact with GitHub Orgs.
"""


class Orgs:
    # pylint: disable=too-many-public-methods
    """
    Interact with GitHub Orgs.
    """

    def __init__(self, client):
        """
        Initialize the Orgs class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def list_organizations(self, payload=None):
        """
        List organizations
        https://docs.github.com/rest/reference/orgs#list-organizations
        Attributes:
        Path Parameters:

        Payload Parameters:
        since-org
         per-page
        """
        url = self._base_url + "/organizations"
        response = self._execute("get", url, payload)
        return response

    def list_custom_repository_roles_in_an_organization(self, organization_id, payload=None):
        """
        List custom repository roles in an organization
        https://docs.github.com/rest/reference/orgs#list-custom-repository-roles-in-an-organization
        Attributes:
        Path Parameters:
        organization_id
        Payload Parameters:

        """
        url = self._base_url + f"/organizations/{organization_id}/custom_roles"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization(self, org, payload=None):
        """
        Get an organization
        https://docs.github.com/rest/reference/orgs#get-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}"
        response = self._execute("get", url, payload)
        return response

    def update_an_organization(self, org, payload=None):
        """
        Update an organization
        https://docs.github.com/rest/reference/orgs/#update-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}"
        response = self._execute("patch", url, payload)
        return response

    def get_the_audit_log_for_an_organization(self, org, payload=None):
        """
        Get the audit log for an organization
        https://docs.github.com/rest/reference/orgs#get-audit-log
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        audit-log-phrase
         audit-log-include
         audit-log-after
         audit-log-before
         audit-log-order
         per-page
        """
        url = self._base_url + f"/orgs/{org}/audit-log"
        response = self._execute("get", url, payload)
        return response

    def list_users_blocked_by_an_organization(self, org, payload=None):
        """
        List users blocked by an organization
        https://docs.github.com/rest/reference/orgs#list-users-blocked-by-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/blocks"
        response = self._execute("get", url, payload)
        return response

    def check_if_a_user_is_blocked_by_an_organization(self, org, username, payload=None):
        """
        Check if a user is blocked by an organization
        https://docs.github.com/rest/reference/orgs#check-if-a-user-is-blocked-by-an-organization
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/blocks/{username}"
        response = self._execute("get", url, payload)
        return response

    def block_a_user_from_an_organization(self, org, username, payload=None):
        """
        Block a user from an organization
        https://docs.github.com/rest/reference/orgs#block-a-user-from-an-organization
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/blocks/{username}"
        response = self._execute("put", url, payload)
        return response

    def unblock_a_user_from_an_organization(self, org, username, payload=None):
        """
        Unblock a user from an organization
        https://docs.github.com/rest/reference/orgs#unblock-a-user-from-an-organization
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/blocks/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_saml_sso_authorizations_for_an_organization(self, org, payload=None):
        """
        List SAML SSO authorizations for an organization
        https://docs.github.com/rest/reference/orgs#list-saml-sso-authorizations-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
         login
        """
        url = self._base_url + f"/orgs/{org}/credential-authorizations"
        response = self._execute("get", url, payload)
        return response

    def remove_a_saml_sso_authorization_for_an_organization(self, org, credential_id, payload=None):
        """
        Remove a SAML SSO authorization for an organization
        https://docs.github.com/rest/reference/orgs#remove-a-saml-sso-authorization-for-an-organization
        Attributes:
        Path Parameters:
        org
        credential_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/credential-authorizations/{credential_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_failed_organization_invitations(self, org, payload=None):
        """
        List failed organization invitations
        https://docs.github.com/rest/reference/orgs#list-failed-organization-invitations
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/failed_invitations"
        response = self._execute("get", url, payload)
        return response

    def list_organization_webhooks(self, org, payload=None):
        """
        List organization webhooks
        https://docs.github.com/rest/reference/orgs#list-organization-webhooks
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/hooks"
        response = self._execute("get", url, payload)
        return response

    def create_an_organization_webhook(self, org, payload=None):
        """
        Create an organization webhook
        https://docs.github.com/rest/reference/orgs#create-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks"
        response = self._execute("post", url, payload)
        return response

    def get_an_organization_webhook(self, org, hook_id, payload=None):
        """
        Get an organization webhook
        https://docs.github.com/rest/reference/orgs#get-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
        response = self._execute("get", url, payload)
        return response

    def update_an_organization_webhook(self, org, hook_id, payload=None):
        """
        Update an organization webhook
        https://docs.github.com/rest/reference/orgs#update-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
        response = self._execute("patch", url, payload)
        return response

    def delete_an_organization_webhook(self, org, hook_id, payload=None):
        """
        Delete an organization webhook
        https://docs.github.com/rest/reference/orgs#delete-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}"
        response = self._execute("delete", url, payload)
        return response

    def get_a_webhook_configuration_for_an_organization(self, org, hook_id, payload=None):
        """
        Get a webhook configuration for an organization
        https://docs.github.com/rest/reference/orgs#get-a-webhook-configuration-for-an-organization
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/config"
        response = self._execute("get", url, payload)
        return response

    def update_a_webhook_configuration_for_an_organization(self, org, hook_id, payload=None):
        """
        Update a webhook configuration for an organization
        https://docs.github.com/rest/reference/orgs#update-a-webhook-configuration-for-an-organization
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/config"
        response = self._execute("patch", url, payload)
        return response

    def list_deliveries_for_an_organization_webhook(self, org, hook_id, payload=None):
        """
        List deliveries for an organization webhook
        https://docs.github.com/rest/reference/orgs#list-deliveries-for-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:
        per-page
         cursor
        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries"
        response = self._execute("get", url, payload)
        return response

    def get_a_webhook_delivery_for_an_organization_webhook(
        self, org, hook_id, delivery_id, payload=None
    ):
        """
        Get a webhook delivery for an organization webhook
        https://docs.github.com/rest/reference/orgs#get-a-webhook-delivery-for-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        delivery_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}"
        response = self._execute("get", url, payload)
        return response

    def redeliver_a_delivery_for_an_organization_webhook(
        self, org, hook_id, delivery_id, payload=None
    ):
        """
        Redeliver a delivery for an organization webhook
        https://docs.github.com/rest/reference/orgs#redeliver-a-delivery-for-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        delivery_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/deliveries/{delivery_id}/attempts"
        response = self._execute("post", url, payload)
        return response

    def ping_an_organization_webhook(self, org, hook_id, payload=None):
        """
        Ping an organization webhook
        https://docs.github.com/rest/reference/orgs#ping-an-organization-webhook
        Attributes:
        Path Parameters:
        org
        hook_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/hooks/{hook_id}/pings"
        response = self._execute("post", url, payload)
        return response

    def list_app_installations_for_an_organization(self, org, payload=None):
        """
        List app installations for an organization
        https://docs.github.com/rest/reference/orgs#list-app-installations-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/installations"
        response = self._execute("get", url, payload)
        return response

    def list_pending_organization_invitations(self, org, payload=None):
        """
        List pending organization invitations
        https://docs.github.com/rest/reference/orgs#list-pending-organization-invitations
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/invitations"
        response = self._execute("get", url, payload)
        return response

    def create_an_organization_invitation(self, org, payload=None):
        """
        Create an organization invitation
        https://docs.github.com/rest/reference/orgs#create-an-organization-invitation
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/invitations"
        response = self._execute("post", url, payload)
        return response

    def cancel_an_organization_invitation(self, org, invitation_id, payload=None):
        """
        Cancel an organization invitation
        https://docs.github.com/rest/reference/orgs#cancel-an-organization-invitation
        Attributes:
        Path Parameters:
        org
        invitation_id
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/invitations/{invitation_id}"
        response = self._execute("delete", url, payload)
        return response

    def list_organization_invitation_teams(self, org, invitation_id, payload=None):
        """
        List organization invitation teams
        https://docs.github.com/rest/reference/orgs#list-organization-invitation-teams
        Attributes:
        Path Parameters:
        org
        invitation_id
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/invitations/{invitation_id}/teams"
        response = self._execute("get", url, payload)
        return response

    def list_organization_members(self, org, payload=None):
        """
        List organization members
        https://docs.github.com/rest/reference/orgs#list-organization-members
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        filter
         role
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/members"
        response = self._execute("get", url, payload)
        return response

    def check_organization_membership_for_a_user(self, org, username, payload=None):
        """
        Check organization membership for a user
        https://docs.github.com/rest/reference/orgs#check-organization-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}"
        response = self._execute("get", url, payload)
        return response

    def remove_an_organization_member(self, org, username, payload=None):
        """
        Remove an organization member
        https://docs.github.com/rest/reference/orgs#remove-an-organization-member
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/members/{username}"
        response = self._execute("delete", url, payload)
        return response

    def get_organization_membership_for_a_user(self, org, username, payload=None):
        """
        Get organization membership for a user
        https://docs.github.com/rest/reference/orgs#get-organization-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/memberships/{username}"
        response = self._execute("get", url, payload)
        return response

    def set_organization_membership_for_a_user(self, org, username, payload=None):
        """
        Set organization membership for a user
        https://docs.github.com/rest/reference/orgs#set-organization-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/memberships/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_organization_membership_for_a_user(self, org, username, payload=None):
        """
        Remove organization membership for a user
        https://docs.github.com/rest/reference/orgs#remove-organization-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/memberships/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_outside_collaborators_for_an_organization(self, org, payload=None):
        """
        List outside collaborators for an organization
        https://docs.github.com/rest/reference/orgs#list-outside-collaborators-for-an-organization
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        filter
         per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/outside_collaborators"
        response = self._execute("get", url, payload)
        return response

    def convert_an_organization_member_to_outside_collaborator(self, org, username, payload=None):
        """
        Convert an organization member to outside collaborator
        https://docs.github.com/rest/reference/orgs#convert-an-organization-member-to-outside-collaborator
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/outside_collaborators/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_outside_collaborator_from_an_organization(self, org, username, payload=None):
        """
        Remove outside collaborator from an organization
        https://docs.github.com/rest/reference/orgs#remove-outside-collaborator-from-an-organization
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/outside_collaborators/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_public_organization_members(self, org, payload=None):
        """
        List public organization members
        https://docs.github.com/rest/reference/orgs#list-public-organization-members
        Attributes:
        Path Parameters:
        org
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/orgs/{org}/public_members"
        response = self._execute("get", url, payload)
        return response

    def check_public_organization_membership_for_a_user(self, org, username, payload=None):
        """
        Check public organization membership for a user
        https://docs.github.com/rest/reference/orgs#check-public-organization-membership-for-a-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/public_members/{username}"
        response = self._execute("get", url, payload)
        return response

    def set_public_organization_membership_for_the_authenticated_user(
        self, org, username, payload=None
    ):
        """
        Set public organization membership for the authenticated user
        https://docs.github.com/rest/reference/orgs#set-public-organization-membership-for-the-authenticated-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/public_members/{username}"
        response = self._execute("put", url, payload)
        return response

    def remove_public_organization_membership_for_the_authenticated_user(
        self, org, username, payload=None
    ):
        """
        Remove public organization membership for the authenticated user
        https://docs.github.com/rest/reference/orgs#remove-public-organization-membership-for-the-authenticated-user
        Attributes:
        Path Parameters:
        org
        username
        Payload Parameters:

        """
        url = self._base_url + f"/orgs/{org}/public_members/{username}"
        response = self._execute("delete", url, payload)
        return response

    def list_organization_memberships_for_the_authenticated_user(self, payload=None):
        """
        List organization memberships for the authenticated user
        https://docs.github.com/rest/reference/orgs#list-organization-memberships-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        state
         per-page
         page
        """
        url = self._base_url + "/user/memberships/orgs"
        response = self._execute("get", url, payload)
        return response

    def get_an_organization_membership_for_the_authenticated_user(self, org, payload=None):
        """
        Get an organization membership for the authenticated user
        https://docs.github.com/rest/reference/orgs#get-an-organization-membership-for-the-authenticated-user
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/user/memberships/orgs/{org}"
        response = self._execute("get", url, payload)
        return response

    def update_an_organization_membership_for_the_authenticated_user(self, org, payload=None):
        """
        Update an organization membership for the authenticated user
        https://docs.github.com/rest/reference/orgs#update-an-organization-membership-for-the-authenticated-user
        Attributes:
        Path Parameters:
        org
        Payload Parameters:

        """
        url = self._base_url + f"/user/memberships/orgs/{org}"
        response = self._execute("patch", url, payload)
        return response

    def list_organizations_for_the_authenticated_user(self, payload=None):
        """
        List organizations for the authenticated user
        https://docs.github.com/rest/reference/orgs#list-organizations-for-the-authenticated-user
        Attributes:
        Path Parameters:

        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + "/user/orgs"
        response = self._execute("get", url, payload)
        return response

    def list_organizations_for_a_user(self, username, payload=None):
        """
        List organizations for a user
        https://docs.github.com/rest/reference/orgs#list-organizations-for-a-user
        Attributes:
        Path Parameters:
        username
        Payload Parameters:
        per-page
         page
        """
        url = self._base_url + f"/users/{username}/orgs"
        response = self._execute("get", url, payload)
        return response



"""
View various OSS licenses.
"""


class Licenses:
    """
    View various OSS licenses.
    """

    def __init__(self, client):
        """
        Initialize the Licenses class.
        """
        self._base_url = client._base_url
        self._execute = client._execute

    def get_all_commonly_used_licenses(self, payload=None):
        """
        Get all commonly used licenses
        https://docs.github.com/rest/reference/licenses#get-all-commonly-used-licenses
        Attributes:
        Path Parameters:

        Payload Parameters:
        featured
         per-page
         page
        """
        url = self._base_url + "/licenses"
        response = self._execute("get", url, payload)
        return response

    def get_a_license(self, license, payload=None):
        # pylint: disable=redefined-builtin
        """
        Get a license
        https://docs.github.com/rest/reference/licenses#get-a-license
        Attributes:
        Path Parameters:
        license
        Payload Parameters:

        """
        url = self._base_url + f"/licenses/{license}"
        response = self._execute("get", url, payload)
        return response

    def get_the_license_for_a_repository(self, owner, repo, payload=None):
        """
        Get the license for a repository
        https://docs.github.com/rest/reference/licenses/#get-the-license-for-a-repository
        Attributes:
        Path Parameters:
        owner
        repo
        Payload Parameters:

        """
        url = self._base_url + f"/repos/{owner}/{repo}/license"
        response = self._execute("get", url, payload)
        return response
